@@ -81,7 +81,7 @@ class FormView(GenericView):
         context = self.get_context_data(form=form)
         return self.render_to_response(context)
 
-    def post(self, request):
+    def post(self, request, *args, **kwargs):
         form = self.get_form(data=request.POST, files=request.FILES)
         if form.is_valid():
             return self.form_valid(form)
